@@ -316,8 +316,10 @@ class ResponseObject(object):
 
 		# check self instance.
 		if isinstance(attributes, ResponseObject):
+			#attributes = attributes.dict()
+			#self = attributes
 			attributes = attributes.dict()
-		if isinstance(json, ResponseObject):
+		elif isinstance(json, ResponseObject):
 			json = json.dict()
 
 		# assign attributes.
@@ -375,9 +377,15 @@ class ResponseObject(object):
 			#except: a=1
 		return self
 	# assign dict.
-	def assign(self, dictionary:dict):
-		for key,value in dictionary.items():
-			self[key] = value
+	def assign(self, dictionary):
+		if isinstance(dictionary, (dict, Dictionary)):
+			for key,value in dictionary.items():
+				self[key] = value
+		elif isinstance(dictionary, (tuple, list, Array)):
+			for key,value in dictionary:
+				self[key] = value
+		else:
+			raise exceptions.InvalidUsage("The dictionary parameter must be a dict or tuple.")
 		return self
 	# crash the error message.
 	def crash(self, error="ValueError", traceback=True, json=False):
